@@ -3,8 +3,10 @@ package Filter::cpp;
 use Config ;
 use Carp ;
 use Filter::Util::Exec ;
+use strict;
+use vars qw($VERSION);
 
-$VERSION = 1.01 ;
+$VERSION = '1.01' ;
 
 sub import 
 { 
